wizard_stepper library
Classes
- WizardStepper
- The actual widget that represents the wizard stepper It is controlled by a controller named WizardStepperController which receives all properties, flags, callbacks, etc. that brings the wizard to life.
- WizardStepperController
- The controller that orchestrates the wizard interactions and the creation of all elements that come together to bring the wizard to life
- WizardStepperDivider
- The widget that represents the division between steps
- WizardStepperEvent
- Represents the event to be dispatched to any listening entities regarding the state of the wizard at various states
- WizardStepperHotSpot
- The widget that represents the step indicator in the wizard
- WizardStepperInheritedTheme
- Provides an inherited widget at the root of the wizard stepper hierarchy in order to provide the theming in a top-down approach
- WizardStepperMetadata
- The metadata associated with each wizard step; this data will be broadcasted and wrapped inside a WizardStepperEvent
- WizardStepperState
- The stateful portion of the WizardStepper widget
- WizardStepperTheme
- Wraps the theme around the wizard stepper
- WizardStepperThemeData
- Encapsulates the theme data for the wizard stepper as far as colors
- WizardStepperViewport
- The widget that represents the viewport through which the step is visible.
Enums
- WizardStepperDividerOrientation
- Describes the orientation of the divider pieces in between the wizard steps
- WizardStepperOrientation
- Describes the display orientation of the wizard steps
- WizardStepperPosition
- Describes the position based on the orientation; top and bottom when WizardStepperOrientation is horizontal, and left and right when WizardStepperOrientation is vertical.
Mixins
- WizardStep
- Mixin that must be added to a given widget that wants to become a step in the wizard; applies to any page-level widget or any widget for that matter, but mostly recommended for top-level widgets. By applying this mixin, a widget can easily query the following information: stepNumber: the corresponding step index in the wizard (zero based) isComplete: whether the step is complete or not isCurrentStep: check whether the step is the current step being viewed completeStep: callback to let the wizard know whether this step is complete or not